@@ -1,27 +1,49 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * DEBUG: section 49    SNMP Interface
+ * AUTHOR: Kostas Anagnostakis
+ *
+ * SQUID Web Proxy Cache          http://www.squid-cache.org/
+ * ----------------------------------------------------------
+ *
+ *  Squid is the result of efforts by numerous individuals from
+ *  the Internet community; see the CONTRIBUTORS file for full
+ *  details.   Many organizations have provided support for Squid's
+ *  development; see the SPONSORS file for full details.  Squid is
+ *  Copyrighted (C) 2001 by the Regents of the University of
+ *  California; see the COPYRIGHT file for full details.  Squid
+ *  incorporates software developed and/or copyrighted by other
+ *  sources; see the CREDITS file for full details.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-/* DEBUG: section 49    SNMP Interface */
-
 #include "squid.h"
-#include "cache_snmp.h"
 #include "CachePeer.h"
+#include "cache_snmp.h"
 #include "globals.h"
 #include "mem_node.h"
 #include "neighbors.h"
 #include "snmp_agent.h"
 #include "snmp_core.h"
+#include "StatCounters.h"
+#include "StatHist.h"
 #include "SquidConfig.h"
 #include "SquidMath.h"
 #include "SquidTime.h"
 #include "stat.h"
-#include "StatCounters.h"
-#include "StatHist.h"
 #include "Store.h"
 #include "tools.h"
 
@@ -223,7 +245,7 @@ snmp_meshPtblFn(variable_list * Var, snint * ErrP)
 
     case MESH_PTBL_ADDR_TYPE: {
         int ival;
-        ival = laddr.isIPv4() ? INETADDRESSTYPE_IPV4 : INETADDRESSTYPE_IPV6 ;
+        ival = laddr.IsIPv4() ? INETADDRESSTYPE_IPV4 : INETADDRESSTYPE_IPV6 ;
         Answer = snmp_var_new_integer(Var->name, Var->name_length,
                                       ival, SMI_INTEGER);
     }
@@ -235,7 +257,7 @@ snmp_meshPtblFn(variable_list * Var, snint * ErrP)
         // See: rfc4001.txt
         Answer->type = ASN_OCTET_STR;
         char host[MAX_IPSTRLEN];
-        laddr.toStr(host,MAX_IPSTRLEN);
+        laddr.NtoA(host,MAX_IPSTRLEN);
         Answer->val_len = strlen(host);
         Answer->val.string =  (u_char *) xstrdup(host);
     }
@@ -430,7 +452,7 @@ snmp_prfProtoFn(variable_list * Var, snint * ErrP)
 
     switch (Var->name[LEN_SQ_PRF + 1]) {
 
-    case PERF_PROTOSTAT_AGGR:   /* cacheProtoAggregateStats */
+    case PERF_PROTOSTAT_AGGR:	/* cacheProtoAggregateStats */
 
         switch (Var->name[LEN_SQ_PRF + 2]) {
 
@@ -612,4 +634,3 @@ snmp_prfProtoFn(variable_list * Var, snint * ErrP)
     *ErrP = SNMP_ERR_NOSUCHNAME;
     return NULL;
 }
-
